import{d as g,ex as v,ey as k,r as d,b as r,c as s,w as a,u as e,f as l,eu as i}from"./registerWidgets.ca57da3e.js";import{S as j,L as w}from"./SmartConsole.9884c3ed.js";import{a as I}from"./asyncComputed.ae0b6a3c.js";import{J as x}from"./jobs.f78a8656.js";import{_ as B}from"./SaveButton.vue_vue_type_script_setup_true_lang.f4f91b79.js";import{_ as C}from"./DocsButton.vue_vue_type_script_setup_true_lang.e215c49e.js";import{B as S}from"./BaseLayout.6a4d2025.js";import{_ as T,a as D}from"./JobSettings.vue_vue_type_script_setup_true_lang.589d7ce5.js";import{c as R}from"./index.3efb162e.js";import{a as _,T as $}from"./index.074f39fb.js";import"./forms.5015911b.js";import"./activeRecord.f8743cd4.js";import"./pubsub.277d05a3.js";import"./dashes.8ed8444a.js";import"./index.56c756a6.js";import"./hooks.60a5ffb4.js";import"./workspaces.0ed1b422.js";import"./icons.1efe7950.js";import"./Title.e5d7f1b0.js";import"./transButton.a2961478.js";import"./FormItem.a9f8aa72.js";import"./uuid.372ac027.js";import"./storage.2a7aac1e.js";import"./dayjs.78e76277.js";import"./index.235a3f30.js";import"./Form.78fca70f.js";import"./index.9943ced7.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="7c035e05-4119-4b9b-ab45-359459b1dc21",n._sentryDebugIdIdentifier="sentry-dbid-7c035e05-4119-4b9b-ab45-359459b1dc21")}catch{}})();const ne=g({__name:"JobEditor",setup(n){const m=v(),c=k(),p=d(null),o=d("test");function y(){m.push({name:"jobs"})}const{result:t}=I(()=>x.get(c.params.jobId)),f=w.create();return(J,b)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(R),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[l(e($),{"active-key":o.value,"onUpdate:activeKey":b[0]||(b[0]=u=>o.value=u)},{default:a(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[l(C),o.value==="settings"?(r(),s(B,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:p,job:e(t),"log-service":e(f)},null,8,["job","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(D,{key:1,job:e(t)},null,8,["job"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(j,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=p.value)==null?void 0:u.test},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=JobEditor.6bb2a318.js.map
