import{v as t,b as s,er as a}from"./registerWidgets.ca57da3e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="444a73f9-a5eb-4552-92ef-5e5596a3834d",e._sentryDebugIdIdentifier="sentry-dbid-444a73f9-a5eb-4552-92ef-5e5596a3834d")}catch{}})();const r={},o={class:"organization-settings"};function i(e,n){return s(),a("div",o,"Organization settings")}const c=t(r,[["render",i]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.d036c19d.js.map
