import{ab as d,U as t,Q as r,f}from"./registerWidgets.ca57da3e.js";import{B as l,b}from"./Title.e5d7f1b0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5695ec1a-560f-4424-b091-7aba3e6f23a6",e._sentryDebugIdIdentifier="sentry-dbid-5695ec1a-560f-4424-b091-7aba3e6f23a6")}catch{}})();const c=()=>t(t({},r(b(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),n=(e,s)=>{let{slots:o,attrs:i}=s;const{ellipsis:a}=e;d();const p=t(t(t({},e),{ellipsis:a&&typeof a=="object"?r(a,["expandable","rows"]):a,component:"span"}),i);return f(l,p,o)};n.displayName="ATypographyText";n.inheritAttrs=!1;n.props=c();const g=n;export{g as A};
//# sourceMappingURL=Text.1f2709b6.js.map
