import{M as r}from"./Modal.db45c3f3.js";import{d as a,G as c,r as d,a as _,b as f,er as l,f as n,w as i,bu as u,e as m,v as p}from"./registerWidgets.ca57da3e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="688291eb-6d9e-4bf4-8995-6a2c88cd4fee",e._sentryDebugIdIdentifier="sentry-dbid-688291eb-6d9e-4bf4-8995-6a2c88cd4fee")}catch{}})();const b=["src"],y=a({__name:"Home",setup(e){const o=c({onboardingForm:""}),t=d(null);return(g,v)=>{const s=_("router-view");return f(),l(u,null,[n(s,{class:"router"}),n(r,{ref_key:"modal",ref:t},{content:i(()=>[m("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const x=p(y,[["__scopeId","data-v-7e290e34"]]);export{x as default};
//# sourceMappingURL=Home.c3b1021b.js.map
