import{d as m,ey as l,H as d,b as c,c as u,u as f,v as _}from"./registerWidgets.ca57da3e.js";import{a as y}from"./asyncComputed.ae0b6a3c.js";import"./gateway.b88d532a.js";import{B as g}from"./build.f0cbfda0.js";import"./index.27945116.js";import{L as b,N as w}from"./icons.1efe7950.js";import{r as I}from"./console.91b51413.js";import{_ as x}from"./CrudView.vue_vue_type_script_setup_true_lang.7b5510ae.js";import{f as v}from"./index.b048d0fb.js";import"./passwordlessManager.8d47b009.js";import"./pubsub.277d05a3.js";import"./storage.2a7aac1e.js";import"./activeRecord.f8743cd4.js";import"./index.56c756a6.js";import"./Form.78fca70f.js";import"./FormItem.a9f8aa72.js";import"./transButton.a2961478.js";import"./index.3efb162e.js";import"./index.9943ced7.js";import"./index.4a64f329.js";import"./index.64def94a.js";import"./dayjs.78e76277.js";import"./index.235a3f30.js";import"./index.dcb9970b.js";import"./index.074f39fb.js";import"./index.f8b9a85c.js";import"./index.a5658a4f.js";import"./index.e15362b2.js";import"./index.888c9e8f.js";import"./index.b0c465bd.js";import"./Title.e5d7f1b0.js";import"./Text.1f2709b6.js";import"./Modal.db45c3f3.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="c5ff9567-80c0-494a-b724-5a18f53af313",o._sentryDebugIdIdentifier="sentry-dbid-c5ff9567-80c0-494a-b724-5a18f53af313")}catch{}})();const B=m({__name:"Builds",setup(o){const r=l().params.projectId,{loading:s,result:n}=y(()=>g.list(r)),p=d(()=>{var a,i;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(i=(a=n.value)==null?void 0:a.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8)},{text:v(t.createdAt,Date.now(),{addSuffix:!0})},{text:t.status+(t.log?": "+t.log:"")},{text:"",actions:[{icon:b,label:"View logs",onClick:()=>I.push({name:"logs",params:{projectId:r},query:{buildId:t.id}})},{icon:w,label:"Download files",onClick:()=>t.download()}]}]})))!=null?i:[]}});return(a,i)=>(c(),u(x,{"entity-name":"build",loading:f(s),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:p.value},null,8,["loading","table"]))}});const rt=_(B,[["__scopeId","data-v-03f70823"]]);export{rt as default};
//# sourceMappingURL=Builds.a442fb7f.js.map
