import{d as b,ex as g,ey as v,r as k,b as r,c as s,w as a,u as e,f as l,eu as i}from"./registerWidgets.ca57da3e.js";import{S as h,L as w}from"./SmartConsole.9884c3ed.js";import{a as x}from"./asyncComputed.ae0b6a3c.js";import{H as B}from"./hooks.60a5ffb4.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.f4f91b79.js";import{_ as H}from"./DocsButton.vue_vue_type_script_setup_true_lang.e215c49e.js";import{B as I}from"./BaseLayout.6a4d2025.js";import{_ as S,a as T}from"./HookSettings.vue_vue_type_script_setup_true_lang.23ca731b.js";import{c as D}from"./index.3efb162e.js";import{a as _,T as R}from"./index.074f39fb.js";import"./forms.5015911b.js";import"./activeRecord.f8743cd4.js";import"./pubsub.277d05a3.js";import"./dashes.8ed8444a.js";import"./index.56c756a6.js";import"./jobs.f78a8656.js";import"./workspaces.0ed1b422.js";import"./icons.1efe7950.js";import"./Title.e5d7f1b0.js";import"./transButton.a2961478.js";import"./FormItem.a9f8aa72.js";import"./uuid.372ac027.js";import"./storage.2a7aac1e.js";import"./index.235a3f30.js";import"./index.a5658a4f.js";import"./index.9943ced7.js";import"./index.e15362b2.js";import"./Form.78fca70f.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="834e9024-bbd6-41c7-a03d-dffe21b978c6",n._sentryDebugIdIdentifier="sentry-dbid-834e9024-bbd6-41c7-a03d-dffe21b978c6")}catch{}})();const ie=b({__name:"HookEditor",setup(n){const m=g(),c=v(),p=k(null),o=k("test");function y(){m.push({name:"hooks"})}const{result:t}=x(()=>B.get(c.params.hookPath)),f=w.create();return($,d)=>(r(),s(I,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[l(e(R),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[l(H,{path:"hooks"}),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(S,{key:0,ref_key:"tester",ref:p,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(T,{key:1,hook:e(t)},null,8,["hook"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=p.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ie as default};
//# sourceMappingURL=HookEditor.7ff37d02.js.map
