import{d as _,ey as w,ex as g,H as b,b as n,er as D,u,c,eu as d,bu as k,v as P}from"./registerWidgets.ca57da3e.js";import{D as I,m as x}from"./DashPlayer.b93e12be.js";import{L as B}from"./CircularLoading.716a5772.js";import{r as R}from"./index.56c756a6.js";import{B as q}from"./BackButton.76588e74.js";import{a as l}from"./asyncComputed.ae0b6a3c.js";import{D as C}from"./dashes.8ed8444a.js";import{W as E}from"./workspaces.0ed1b422.js";import"./executeJs.c4f1fb52.js";import"./PlayerNavbar.dd762667.js";import"./icons.1efe7950.js";import"./Steps.2df1321f.js";import"./Modal.db45c3f3.js";import"./geometryUtils.71fcc059.js";import"./passwordlessManager.8d47b009.js";import"./pubsub.277d05a3.js";import"./storage.2a7aac1e.js";import"./Passwordless.dec7e85f.js";import"./WidgetsFrame.7a78af2f.js";import"./activeRecord.f8743cd4.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="ebd782a0-af29-4b80-8be1-62ac71431f31",t._sentryDebugIdIdentifier="sentry-dbid-ebd782a0-af29-4b80-8be1-62ac71431f31")}catch{}})();const F=_({__name:"DashPreview",setup(t){const r=w(),s=g(),m=({id:e,type:o})=>{o==="dash"?(s.push({name:"dashPreview",params:{dashId:e},query:r.query}),y()):s.push({name:"formPreview",params:{formId:e},query:r.query})},f=()=>{var e;!((e=a.value)!=null&&e.path)||s.push(`/_editor/dash/${encodeURIComponent(a.value.path)}`)},{loading:v,result:a,refetch:y}=l(()=>C.get(r.params.dashPath)),{result:i}=l(()=>E.get()),p=b(()=>{if(!a.value||!i.value||!a.value.makeRunnerData(i.value))return null;const e=x(a.value.makeRunnerData(i.value));return e.onRedirect(({url:o,queryParams:h})=>R("preview",s,o,h)),e});return(e,o)=>(n(),D(k,null,[u(v)||!u(a)?(n(),c(B,{key:0,class:"loading",justify:"center"})):d("",!0),p.value?(n(),c(I,{key:1,class:"player",dash:p.value.runnerData,"widgets-with-errors":[],"is-preview":!0,params:u(r).query,"dash-player-service":p.value,onNavigate:m},null,8,["dash","params","dash-player-service"])):d("",!0),u(a)?(n(),c(q,{key:2,onExitFullscreenPreview:f})):d("",!0)],64))}});const Z=P(F,[["__scopeId","data-v-1172cf43"]]);export{Z as default};
//# sourceMappingURL=DashPreview.be941c40.js.map
