import{cL as r}from"./registerWidgets.ca57da3e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="88d7e6d2-08e4-4652-9ca6-63f34dbd9fb3",e._sentryDebugIdIdentifier="sentry-dbid-88d7e6d2-08e4-4652-9ca6-63f34dbd9fb3")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.1fd3422a.js.map
