import{d as f,ey as b,H as u,b as y,c as _,u as g}from"./registerWidgets.ca57da3e.js";import{a as w}from"./asyncComputed.ae0b6a3c.js";import"./gateway.b88d532a.js";import{M as n}from"./member.31e7d30e.js";import"./index.27945116.js";import{_ as I}from"./CrudView.vue_vue_type_script_setup_true_lang.7b5510ae.js";import"./passwordlessManager.8d47b009.js";import"./pubsub.277d05a3.js";import"./storage.2a7aac1e.js";import"./activeRecord.f8743cd4.js";import"./Modal.db45c3f3.js";import"./Title.e5d7f1b0.js";import"./transButton.a2961478.js";import"./index.b0c465bd.js";import"./Text.1f2709b6.js";import"./index.e15362b2.js";import"./index.9943ced7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="79b45733-ab94-40db-943c-e96fefe732f5",e._sentryDebugIdIdentifier="sentry-dbid-79b45733-ab94-40db-943c-e96fefe732f5")}catch{}})();const j=f({__name:"Members",setup(e){const a=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(a,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(a)),c=u(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?r:[]}});return(t,r)=>(y(),_(I,{"entity-name":"members",loading:g(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{j as default};
//# sourceMappingURL=Members.8a787cbe.js.map
