import{S as c}from"./Sidebar.76bf6a9e.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.0bbf63d7.js";import{D as d,E as l,F as u}from"./icons.1efe7950.js";import{d as b,ey as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./registerWidgets.ca57da3e.js";import{a as w}from"./asyncComputed.ae0b6a3c.js";import"./gateway.b88d532a.js";import{O as z}from"./organization.ac190c20.js";import"./index.27945116.js";import{B as h}from"./BaseLayout.6a4d2025.js";import"./Tooltip.b630d11d.js";import"./logo.084e5d7c.js";import"./passwordlessManager.8d47b009.js";import"./pubsub.277d05a3.js";import"./storage.2a7aac1e.js";import"./Text.1f2709b6.js";import"./Title.e5d7f1b0.js";import"./transButton.a2961478.js";import"./index.9943ced7.js";import"./index.3efb162e.js";import"./activeRecord.f8743cd4.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ed15cbc4-8fdf-484c-a66c-ed7fd9e452db",e._sentryDebugIdIdentifier="sentry-dbid-ed15cbc4-8fdf-484c-a66c-ed7fd9e452db")}catch{}})();const J=b({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.390ca56c.js.map
