import{F as y,o as p,eq as O,d as S,U as i,f as h,R as c,b8 as u}from"./registerWidgets.ca57da3e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c940dd2d-91cd-4293-af12-756c63a4e26a",e._sentryDebugIdIdentifier="sentry-dbid-c940dd2d-91cd-4293-af12-756c63a4e26a")}catch{}})();const D=()=>{const e=y(!1);return p(()=>{e.value=O()}),e};var x=globalThis&&globalThis.__rest||function(e,a){var l={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&a.indexOf(t)<0&&(l[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,t=Object.getOwnPropertySymbols(e);o<t.length;o++)a.indexOf(t[o])<0&&Object.prototype.propertyIsEnumerable.call(e,t[o])&&(l[t[o]]=e[t[o]]);return l};const C={border:0,background:"transparent",padding:0,lineHeight:"inherit",display:"inline-block"},E=S({compatConfig:{MODE:3},name:"TransButton",inheritAttrs:!1,props:{noStyle:{type:Boolean,default:void 0},onClick:Function,disabled:{type:Boolean,default:void 0},autofocus:{type:Boolean,default:void 0}},setup(e,a){let{slots:l,emit:t,attrs:o,expose:b}=a;const r=y(),g=n=>{const{keyCode:d}=n;d===u.ENTER&&n.preventDefault()},v=n=>{const{keyCode:d}=n;d===u.ENTER&&t("click",n)},m=n=>{t("click",n)},f=()=>{r.value&&r.value.focus()},w=()=>{r.value&&r.value.blur()};return p(()=>{e.autofocus&&f()}),b({focus:f,blur:w}),()=>{var n;const{noStyle:d,disabled:_}=e,k=x(e,["noStyle","disabled"]);let s={};return d||(s=i({},C)),_&&(s.pointerEvents="none"),h("div",c(c(c({role:"button",tabindex:0,ref:r},k),o),{},{onClick:m,onKeydown:g,onKeyup:v,style:i(i({},s),o.style||{})}),[(n=l.default)===null||n===void 0?void 0:n.call(l)])}}}),B=E;export{B as T,D as u};
//# sourceMappingURL=transButton.a2961478.js.map
